@@ -1,8 +1,10 @@
 __title__ = 'vishap.conf'
 __author__ = 'Artur Barseghyan'
-__copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2013-2015 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('get_setting', 'set_setting', 'settings', 'reset_to_defaults_settings')
+__all__ = (
+    'get_setting', 'set_setting', 'settings', 'reset_to_defaults_settings',
+)
 
 from vishap import defaults
 
